<?php
/**
 * @version		$Id: econtent_utility.php 189 2009-09-15 10:58:00 econtentsupport@gmail.com $
 * @package		Econtent
 * @subpackage		econtent utility
 * @author 		E-Content 
 * @license		GNU/GPL, see http://www.fsf.org/licensing/licenses/gpl-howto.html
 */

/**
* @Copyright Copyright (C) 2010- econtent
* @license GNU/GPL http://www.gnu.org/copyleft/gpl.html
**/

/**
 * @package		Econtent
 * @subpackage		econtent utility
 */
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

/**
 * Econtent Utility class
 * Store many useful functions
 *
 */
class Econtent_utility
{
	/**
	 * Convert an array to string
	 *
	 * @param array $arr_input
	 * @param string $str_separate
	 * @return string
	 */
	function econtent_array_to_string($arr_input, $str_separate){
		$str_output = "";
		for ($i = 0; $i < count($arr_input); $i++){
			if ($i == 0) {
				$str_output = $arr_input[$i];
			}else {
				$str_output .= $str_separate . $arr_input[$i];
			}
		}
		return $str_output;
	}
	
	/**
	 * Convert an string to an array
	 *
	 * @param string $str_input
	 * @param string $str_separate
	 * @return array
	 */
	function econtent_string_to_array($str_input, $str_separate){
		$arr_output = split($str_separate, $str_input);
		return $arr_output;
	}
	
	/**
	 * Is sub array (sequential)
	 * A smarter detect, uses for getUpdateElement function
	 *
	 * @param array $newArray
	 * @param array $oldArray
	 * @return bool
	 */
	function isSubArray($newArray, $oldArray) {
		$d = -1;
		for ($i = 0; $i < count($newArray) && $i < count($oldArray); $i++){
			$ok = false;
			for ($j = 0; $j < count($oldArray); $j++){
				if(($newArray[$i] == $oldArray[$j]) && ($j > $d)){
					$d = $j;
					$ok = true;
					break;
				}
			}
			if (!$ok) {
				return false;
			}
		}
		
		return true;
	}
	
	/**
	 * Get Update Elements
	 * Get updated elements by compare 2 arrays
	 *
	 * @param array $newArray
	 * @param array $oldArray
	 * @return array
	 */
	function getUpdateElement($newArray, $oldArray){
		$k = 0;
		$allNew = true;
		for ($i = 0; $i < count($newArray); $i++){
			$subArray = array_slice($newArray, $i, count($newArray) - $i);
			if (Econtent_utility::isSubArray($subArray, $oldArray)) {
				$k = $i;
				$allNew = false;
				break;
			}
		}
		
		$returnArray = array_slice($newArray, 0, $k);
		
		if ($allNew) {
			return $newArray;
		}
		
		return $returnArray;
	}
	
	/**
	 * split an array to many array
	 * each array length less than $size
	 *
	 * @param array $arr_input
	 * @param int $size
	 * @return array
	 */
	function splitArray($arr_input, $size){
		$arr_output = array();
		
		$i = 0;
		do {
			$arr_temp = array_slice($arr_input, $i, $size);
			array_push($arr_output, $arr_temp);
			$i += $size;
		} while ($i < count($arr_input));
		
		return $arr_output;
	}
	
	/**
	 * Get a sub words from a string
	 *
	 * @param string $str_in string input
	 * @param int $numberWord Number of words
	 * @param int $start point to start get words
	 * @return string
	 */
	function wordSub($str_in, $numberWord, $start = 0) {
		$arr_text = preg_split('/\s/',trim($str_in));
		$arr_new = array_slice($arr_text, $start, $numberWord);
		$text = implode(' ', $arr_new);
		return $text;
	}
	
	
	/**
	 * Make a string HTML input safe
	 *
	 * @param String HTML $data
	 * @return String HTML
	 */
	function makesafehtml($data){
		$subtext	=	$data;
		$subtext	=	preg_replace('/<table.*?>.*?<\/table>/si','', $subtext );
		$subtext	=	preg_replace('/<select.*?>.*?<\/select>/si','',$subtext);
		$subtext	=	preg_replace('/<script.*?>.*?<\/script>/si','', $subtext);
		$subtext	=	preg_replace('/<\!--.*?-->/si','', $subtext);
		$subtext	=	preg_replace('/<br>/si','<br />', $subtext);
		
		if(preg_match_all('/<(img|hr|br|input)(.*?)>/si',$subtext, $matches)){
			for ($i = 0; $i < count($matches[2]); $i++){
				$strIn = $matches[2][$i];
				if ((strlen($strIn) == 0) || ($strIn[strlen($strIn) - 1] != '/')) {
					$newStrIn = $strIn . '/';
					$subtext = str_replace('<'.$matches[1][$i].$strIn.'>', '<'.$matches[1][$i].$newStrIn.'>', $subtext);
				}
			}
		}
		
		preg_match_all('/<(?!\/).*?>/', $subtext, $matches);
		$arr_open = $matches[0];
		preg_match_all('/<\/.*?>/', $subtext, $matches);
		$arr_close = $matches[0];
		for ($i =0; $i<count($arr_open); $i++){
			if (preg_match('/<.*?\/>/i', $arr_open[$i])) {
				$arr_open = $this->delAnArrayElement($i, $arr_open);
				$i--;
			}
		}		
		
		$carr_open	=	$arr_open;
		$carr_close	=	$arr_close;
		
		for ($i	=	0; $i< count($arr_open); $i++){			
			for ($j = 0; $j<count($arr_close); $j++){
				preg_match('/<(\S+)?\s*.*?>/i', $arr_open[$i], $match);
				preg_match('/<\/(\S+)?>/', $arr_close[$j], $match1);
				if ($match[1]==$match1[1]) {
					$arr_open	=	$this->delAnArrayElement($i, $arr_open);
					$arr_close	=	$this->delAnArrayElement($j, $arr_close);
					$i--;
					break;
				}
			}			
		}
		
	
		for ($i	=	count($carr_close)-1; $i>=0; $i--){			
			for ($j = count($carr_open)-1; $j>=0; $j--){
				preg_match('/<(\S+)?\s*.*?>/i', $carr_open[$j], $match);
				preg_match('/<\/(\S+)?>/', $carr_close[$i], $match1);
				if ($match[1]==$match1[1]) {					
					$carr_open	=	$this->delAnArrayElement($j, $carr_open);
					$carr_close	=	$this->delAnArrayElement($i, $carr_close);					
					break;
				}
			}			
		}		
		
		
		$tagclose	=	'';
		$tagopen	=	'';
		
		for ($i = 0 ; $i<count($arr_open); $i++){
			preg_match('/<(\S+)?\s*.*?>/i', $arr_open[$i], $match);
			$tagclose	=	'</'.$match[1].'>'.$tagclose;
		}
		
		for ($i = 0 ; $i<count($carr_close); $i++){
			preg_match('/<\/(.+?)>/i', $carr_close[$i], $match);
			$tagopen	=	'<'.$match[1].'>'. $tagopen;
		}
		
		$data	.=	$tagclose;
		$data	=	$tagopen.$data;
		return $data;
		
	}
	
	function delAnArrayElement($i,$array){
		$newarray	=	array();
		for ($j=0; $j<count($array); $j++){
			if ($j!=$i) {
				array_push($newarray, $array[$j]);
			}
		}
		return $newarray;
	}
	
	function getVersion(){
		$xml = & JFactory::getXMLParser('Simple');
		if ($xml->loadFile(JPATH_COMPONENT_ADMINISTRATOR.DS.'helpers'.DS.'version.xml'))
		{
			if (!$version = & $xml->document->version) {
				return false;
			}
			if (!$url = & $xml->document->url) {
				return false;
			}
			if (!$productcode = & $xml->document->productcode) {
				return false;
			}
		} else {
			return false;
		}
		
		return array('version' => $version[0]->data(), 'url' => $url[0]->data(), 'productcode'=> $productcode[0]->data() );
		
	}
}
?>
